# vim: set ts=4 sw=4 et:
#
# spec file for package lzlib
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           lzlib
%define lname liblz1
Version:        1.7
Release:        6.5
Summary:        LZMA Compression and Decompression Library
License:        GPL-2.0+
Group:          Development/Libraries/C and C++
Url:            http://www.nongnu.org/lzip/lzlib.html

Source:         http://download.savannah.gnu.org/releases/lzip/lzlib/%name-%version.tar.gz
Source2:        http://download.savannah.gnu.org/releases/lzip/lzlib/%name-%version.tar.gz.sig
Source3:        %name.keyring
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
PreReq:         %install_info_prereq

%description
The lzlib compression library provides in-memory LZMA compression and
decompression functions, including integrity checking of the
decompressed data. The compressed data format used by the library is
the lzip format.

%package -n %lname
Summary:        LZMA Compression and Decompression Library
Group:          System/Libraries

%description -n %lname
The lzlib compression library provides in-memory LZMA compression and
decompression functions, including integrity checking of the
decompressed data. The compressed data format used by the library is
the lzip format.

%package devel
Summary:        LZMA Compression and Decompression Library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Obsoletes:      lzlib-devel < %version-%release
Provides:       lzlib-devel = %version-%release

%description devel
The lzlib compression library provides in-memory LZMA compression and
decompression functions, including integrity checking of the
decompressed data. The compressed data format used by the library is
the lzip format.

This subpackage contains libraries and header files for developing
applications that want to make use of libcerror.

%prep
%setup -q

%build
# not autoconf!
# don't use the configure macro here, as it will cause the configure script to
# skip parameters as soon as it encounters one that it doesn't understand
./configure \
    --prefix="%{_prefix}" \
    --bindir="%{_bindir}" \
    --datadir="%{_datadir}" \
    --includedir="%{_includedir}" \
    --infodir="%{_infodir}" \
    --libdir="%{_libdir}" \
    --mandir="%{_mandir}" \
    --sysconfdir="%{_sysconfdir}" \
    --enable-shared \
    CXX="%__cxx" \
    CPPFLAGS="%{optflags}" \
    CXXFLAGS="%{optflags}"

make %{?_smp_flags}

%install
make DESTDIR="%{buildroot}" LDCONFIG=echo install
# configure had no --disable-static
rm -f "%buildroot/%_libdir"/*.a

%check
make check

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%post devel
%install_info --info-dir="%_infodir" "%_infodir/%name.info%ext_info"

%postun devel
%install_info_delete --info-dir="%_infodir" "%_infodir/%name.info%ext_info"

%files -n %lname
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING NEWS README
%{_libdir}/liblz.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/lzlib.h
%{_libdir}/liblz.so
%doc %{_infodir}/lzlib.info%{ext_info}

%changelog
* Thu Aug  6 2015 jengelh@inai.de
- Update to new upstream release 1.7
  * The fast encoder, which produces a compression speed and ratio
  comparable to those of gzip, has been ported from lzip.
  * The option "-0" has been ported from lzip to minilzip.
  * If all the data to be compressed are written in advance, lzlib
  will automatically adjust the header of the compressed data to
  use the smallest possible dictionary size. This feature reduces
  the amount of memory needed for decompression and allows minilzip
  to produce identical compressed output as lzip.
* Wed Oct  1 2014 jengelh@inai.de
- Update to new upstream release 1.6
  * Compression ratio of option -9 has been slightly increased.
  * Minilzip now copies file dates, permissions, and ownership like
  `cp -p`. (If the user ID or the group ID cannot be duplicated,
  the file permission bits S_ISUID and S_ISGID are cleared).
  * The license has been changed to "GPL version 2 or later with link
  exception".
* Tue Sep 23 2014 jengelh@inai.de
- Drop gpg-offline build-time requirement; this is now handled by
  the local source validator
* Sun Sep 29 2013 jengelh@inai.de
- Update to new upstream release 1.5
  * Decompression support for deprecated version 0 files has been
  removed.
  * A bug has been fixed that would make an instance of
  "struct LZ_Encoder" unresponsive if "LZ_compress_sync_flush" were
  called at the wrong moment.
* Wed Jun  5 2013 jengelh@inai.de
- Update to new upstream release 1.4
  * Compression ratio has been slightly increased.
  * Compression time has been reduced by 8%%.
  * Decompression time has been reduced by 7%%.
  * Arguments and return values of functions in lzlib.h have been
  changed from "long long" to "unsigned long long".
  * "LZ_decompress_read" now tells "header error" from "unexpected
  eof" the same way as lzip does when the EOF happens at the header.
- Do signature verification
- Base name of devel package on main name
- Remove static libraries from installation
- Wrap description at 70 cols
* Thu Apr 12 2012 pascal.bleser@opensuse.org
- update to 1.3:
  * Lzlib has been translated to C from the C++ source of lzlib 1.2. This has
    been done to avoid the dependency on libstdc++, making lzlib useful in more
    environments
* Sun Jan 29 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
* Thu Oct 27 2011 pascal.bleser@opensuse.org
- update to 1.2:
  * for large values of "--match-length", compression ratio has been slightly
    increased and compression time has been reduced by up to 6%%
  * the option "-F, --recompress", which forces recompression of files whose
    name already has the ".lz" or ".tlz" suffix, has been added to minilzip
* Wed Dec  8 2010 pascal.bleser@opensuse.org
- update to 1.0:
  * new functions: LZ_decompress_member_finished, LZ_decompress_member_version,
    LZ_decompress_dictionary_size, LZ_decompress_data_crc
  * variables declared "extern" have been encapsulated in a namespace
  * a warning about fchown's return value being ignored has been fixed
  * input_buffer has been integrated in Range_decoder, simplifying the code and
    making decompression slightly faster
- SONAME changed from 0 to 1
* Mon Feb 15 2010 pascal.bleser@opensuse.org
- update to 0.9:
  * compression time has been reduced by 8%%
* Tue Jan 19 2010 pascal.bleser@opensuse.org
- initial package (0.8)
